==> haskell-xmlgen-0.6.2.2-186-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xmlgen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmlgen
version:              0.6.2.2
visibility:           public
id:                   xmlgen-0.6.2.2-4YKaj1IcjkME4Y2PV7OJrk
key:                  xmlgen-0.6.2.2-4YKaj1IcjkME4Y2PV7OJrk
license:              BSD-3-Clause
maintainer:           Stefan Wehr <wehr@factisresearch.com>
author:
    Stefan Wehr, Stefan Schmidt, Johannes Weiss, David Leuschner

synopsis:             Fast XML generation library
description:          Library for high-performance XML generation.
category:             Text, XML
abi:                  5dc56ba6cfcbcabeaffba47524878a7f
exposed:              True
exposed-modules:      Text.XML.Generator
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xmlgen
hs-libraries:         HSxmlgen-0.6.2.2-4YKaj1IcjkME4Y2PV7OJrk
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-ANrFLGaR0ME9lTajIuX8Fb
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-xmlgen/html/xmlgen.haddock
haddock-html:         /usr/share/doc/haskell-xmlgen/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xmlgen-0.6.2.2-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xmlgen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmlgen
version:              0.6.2.2
visibility:           public
id:                   xmlgen-0.6.2.2-3bKyE4fKcKE3AO2RXsz1iJ
key:                  xmlgen-0.6.2.2-3bKyE4fKcKE3AO2RXsz1iJ
license:              BSD-3-Clause
maintainer:           Stefan Wehr <wehr@factisresearch.com>
author:
    Stefan Wehr, Stefan Schmidt, Johannes Weiss, David Leuschner

synopsis:             Fast XML generation library
description:          Library for high-performance XML generation.
category:             Text, XML
abi:                  a928632a61bb71c80664f41cf743df3b
exposed:              True
exposed-modules:      Text.XML.Generator
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xmlgen
hs-libraries:         HSxmlgen-0.6.2.2-3bKyE4fKcKE3AO2RXsz1iJ
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-6YvA6FikElyHVllPu1Wc2a
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-xmlgen/html/xmlgen.haddock
haddock-html:         /usr/share/doc/haskell-xmlgen/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
